=================================
apache-airflow-providers-teradata
=================================


.. image:: https://img.shields.io/pypi/v/apache_airflow_providers_teradata.svg
        :target: https://pypi.python.org/pypi/apache_airflow_providers_teradata

.. image:: https://img.shields.io/travis/flolas/apache_airflow_providers_teradata.svg
        :target: https://travis-ci.com/flolas/apache_airflow_providers_teradata

.. image:: https://readthedocs.org/projects/apache-airflow-providers-teradata/badge/?version=latest
        :target: https://apache-airflow-providers-teradata.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/flolas/apache_airflow_providers_teradata/shield.svg
     :target: https://pyup.io/repos/github/flolas/apache_airflow_providers_teradata/
     :alt: Updates
